**********************************************************
**Session: Cleaning
**Purpose: SOEP data cleaning
**Author:  Michele Ubaldi
**Date:    December 17, 2024
**********************************************************
***Begin 2nd part

clear all
set maxvar 32000

**Read in the data created in session ``Merging''
cd "C:\Users\your_folder_path\"
use gross_soepv36eu.dta, clear

count
tab syear
 
****************************************************
****************************************************
**Dependent variables
****************************************************
****************************************************
 
******Overall life satisfaction*******
fre p11101
rename p11101 lifesat
recode lifesat -7 -6 -5 -4 -3 -2 -1=.
label var lifesat "Life satisfaction"

******Body-Mass Index******
fre bmi if bmi<0
recode bmi -8 -7 -6 -5 -4 -3 -2 -1=.
label var bmi "Body-Mass Index (already computed)"

******Body height******
fre height
recode height -8 -7 -6 -5 -4 -3 -2 -1=.
label var height "Individual height"

******Body weight******
fre weight
recode weight -8 -7 -6 -5 -4 -3 -2 -1=.
label var weight "Individual weight"

****SF-12v2 mental (MCS) and physical (PCS) variables****
***Current health (ITEM 1)***
fre ple0008
rename ple0008 currhea
label var currhea "Current health - SF12 item 1"
recode currhea -8 -7 -6 -5 -4 -3 -2 -1=.

***State of health affects ascending stairs (ITEM 2)***
fre ple0004
rename ple0004 hinstai
label var hinstai "State of health affects ascending stairs - SF12 item 2"
recode hinstai -8 -7 -6 -5 -4 -3 -2 -1=.

***State of health affects tiring tasks (ITEM 3)***
fre ple0005
rename ple0005 tir
label var tir "State of health affects tiring tasks - SF12 item 3"
recode tir -8 -7 -6 -5 -4 -3 -2 -1=.

***Pressed for time last 4 weeks (ITEM 4)***
fre ple0026
rename ple0026 rush
label var rush "Pressed for time last 4 weeks - SF12 item 4"
recode rush -8 -7 -6 -5 -4 -3 -2 -1=.

***Run-down, melancholy last 4 weeks (ITEM 5)***
fre ple0027
rename ple0027 mela
label var mela "Run-down, melancholy last 4 weeks - SF12 item 5"
recode mela -8 -7 -6 -5 -4 -3 -2 -1=.

***Well-balanced last 4 weeks (ITEM 6)***
fre ple0028
rename ple0028 relax
label var relax "Well-balanced last 4 weeks - SF12 item 6"
recode relax -8 -7 -6 -5 -4 -3 -2 -1=.

***Used energy last 4 weeks (ITEM 7)***
fre ple0029
rename ple0029 energy
label var energy "Used energy last 4 weeks - SF12 item 7"
recode energy -8 -7 -6 -5 -4 -3 -2 -1=.

***Physical pain last four weeks (ITEM 8)***
fre ple0030
rename ple0030 phypain
label var phypain "Physical pain last four weeks - SF12 item 8"
recode phypain -8 -7 -6 -5 -4 -3 -2 -1=.

***Limitations due to physical problems (ITEM 9)***
fre ple0032
rename ple0032 lesswan_phy
label var lesswan_phy "Limitations due to physical problems - SF12 item 9"
recode lesswan_phy -8 -7 -6 -5 -4 -3 -2 -1=.

***Accomplished less due to physical problems (ITEM 10)***
fre ple0031
rename ple0031 accomles_phy
label var accomles_phy "Accomplished less due to physical problems - SF12 item 10"
recode accomles_phy -8 -7 -6 -5 -4 -3 -2 -1=.

***Accomplished less due to emotional problems (ITEM 11)***
fre ple0033
rename ple0033 accomles_men
label var accomles_men "Accomplished less due to emotional problems - SF12 item 11"
recode accomles_men -8 -7 -6 -5 -4 -3 -2 -1=.

***Less careful due to emotional problems (ITEM 12)***
fre ple0034
rename ple0034 careless_men
label var careless_men "Less careful due to emotional problems - SF12 item 12"
recode careless_men -8 -7 -6 -5 -4 -3 -2 -1=.

***Limited socially due to health (ITEM 13)***
fre ple0035
rename ple0035 soclim
label var soclim "Limited socially due to health - SF12 item 13"
recode soclim -8 -7 -6 -5 -4 -3 -2 -1=.

***MCS: Summary scale for mental health (NBS)***
recode mcs -8 -7 -6 -5 -4 -3 -2 -1=.
label var mcs "MCS: Summary scale mental health (NBS) - (already computed)"

***PCS: Summary scale for psychal health (NBS)***
recode pcs -8 -7 -6 -5 -4 -3 -2 -1=.
label var pcs "PCS: Summary scale physical health (NBS) - (already computed)"

******Frequency of alcohol consumption******
fre ple0177
rename ple0177 alccon
recode alccon -8 -7 -6 -5 -4 -3 -2 -1=.
label var alccon "Frequency of alcohol consumption"

******Frequency of beer consumption******
fre ple0090
rename ple0090 becon
recode becon -8 -7 -6 -5 -4 -3 -2 -1=.
label var becon "Frequency of beer consumption"

******Frequency of wine consumption******
fre ple0091
rename ple0091 wicon
recode wicon -8 -7 -6 -5 -4 -3 -2 -1=.
label var wicon "Frequency of wine consumption"

******Frequency of spirits consumption******
fre ple0092
rename ple0092 spicon
recode spicon -8 -7 -6 -5 -4 -3 -2 -1=.
label var spicon "Frequency of spirits consumption"

******Frequency of mixed drinks consumption******
fre ple0093
rename ple0093 mixcon
recode mixcon -8 -7 -6 -5 -4 -3 -2 -1=.
label var mixcon "Frequency of mixed drinks consumption"

****Currently smoking***
fre ple0081_h
rename ple0081_h smoke
recode smoke -8 -7 -6 -5 -4 -3 -2 -1=.
label var smoke "Currently smoking"


****************************************************
****************************************************
**Treatment variables
****************************************************
****************************************************

**Key inedependent variable: Job termination due to plant closure -- Harmonized
**Note: asked since 1991 and not asked in 1999 and 2000
fre plb0304_h
tab plb0304_h syear if syear>=1991
rename plb0304_h unempreason
recode unempreason -8 -7 -5 -3 -2 -1=.
 
****************************************************
****************************************************
**Socio-Demographics
****************************************************
****************************************************
 
*****Age********
fre d11101
rename d11101 age
recode age -7 -1=.
fre age
 
****Education with respect to highschool*****
fre d11108
rename d11108 educdum
recode educdum -7 -6 -5 -4 -3 -2 -1=.
fre educdum
 
*****No child -within HH-
ren d11107 nokid
recode nokid -7 -5 -2=.
fre nokid
 
****State of residence****
fre l11101
rename l11101 state
recode state -7 -6 -5 -4 -3 -2 -1=.
fre state
 
****HH labor income***
rename i11103 hhinc_labor
recode hhinc_labor -7 -5 -2=.
sum hhinc_labor
 
***HH income from assets****
rename i11104 hhinc_asset
recode hhinc_asset -7 -5 -2=.
 
****Income from self-employment***
rename iself inc_self
recode inc_self -7 -5 -2=.
sum inc_self
 
****Individual labor earnings****
rename i11110 inc_labor
recode inc_labor -7 -5 -2=.
sum inc_labor

****Losing job-expectations in next 2 years -- version 1 (valid for 1985, 1987, 1989/1994, 1996, 1998)****
fre plb0433_v1
rename plb0433_v1 job_explose1
recode job_explose1 -8 -7 -6 -5 -4 -3 -2 -1=.

****Losing job-expectations in next 2 years -- version 1 (valid from 1999 to 2018)****
fre plb0433_v2
rename plb0433_v2 job_explose2
recode job_explose2 -8 -7 -6 -5 -4 -3 -2 -1=.
 
****HH post government income (disposable income)****
*fre i11102
ren i11102 dispinc
recode dispinc -7 -5 -2=.
gen dispinc1 = dispinc
replace dispinc1 = 1 if dispinc==0
gen logdispinc = log(dispinc)
gen logdispinc1 = log(dispinc1)
drop dispinc1
 
****Employment status (occupational position)****
tab pgstib
fre pgstib                              
rename pgstib occ
recode occ -7 -6 -5 -4 -3 -2 -1=.
tab occ, m

****Generate self-employment categories****
gen selfemp = (inrange(occ, 410, 440))
replace selfemp = . if occ==.
label var selfemp "Self-employed, based on var wecce04187, codes 410-440"
tab occ selfemp, m

****Generate civil servant categories****
gen civils = (inrange(occ, 610, 640))
replace civils = . if occ==.
label var civils "Civil servant, based on var wecce04187, codes 610-640"
tab occ civils, m

****Military****
gen military = (inrange(occ, 15, 15))
replace military = . if occ==.
label var military "Military, based on var wecce04187, codes 15"
tab occ military, m

****Pensioner****
gen pensioner = (inrange (occ, 13, 13))
replace pensioner = . if occ==.
label var pensioner "Pensioner, based on var wecce04187, codes 13"
tab occ pensioner, m

****Not employed****
gen notemp = (inrange (occ, 10,10))
replace notemp = . if occ==.
label var notemp "not employed, based on var wecce04187, codes 10"
tab occ notemp, m
 
****Currently in education****
gen cureduc = (inrange (occ, 11,11))
replace cureduc = . if occ==.
label var cureduc "Currently in educ, based on var wecce04187, codes 11"
tab occ cureduc, m

****Registered unemployed****
gen regunemp = (inrange (occ, 12, 12))
replace regunemp = . if occ==.
label var regunemp "Registered unemloyed, based on var wece04187, code12"
tab occ regunemp
 
****Private paid employees [GENERATED]****
gen privemp = (inrange (occ, 110,150))
replace privemp = 1 if occ>=210 & occ<=250
replace privemp = 1 if occ>=510 & occ<=550
replace privemp=. if occ==.
tab occ privemp
label var privemp "Private emp, var wece04187, codes 110-150, 210-250, 510-550"

local lm "hhinc* inc* *emp* unemp* job*" 
foreach var of varlist `lm'{
	replace `var' = . if `var'<0
}

****West Germany****
fre l11102
rename l11102 west
recode west 2=0
recode west -7 -6 -5 -4 -3 -2 -1=.

****House size in sqd meters****
fre hgsize
recode hgsize -8 -7 -6 -5 -4 -3 -2 -1=.
 
****Generate future income****
sort pid syear
by pid : gen dispinclead = dispinc[_n+1]
 
****Unemployment experience - Total length of unemployment up to the point of the intervew****
fre pgexpue
recode pgexpue -7 -6 -5 -4 -3 -2 -1=.
 
****Worried about job security****
fre plh0042
rename plh0042 jobsecworry
recode jobsecworry -8 -7 -6 -5 -4 -3 -2 -1=.

****Month of interview****
fre pgmonth
recode pgmonth -8 -7 -6 -5 -4 -3 -2 -1=.

****Create a relationship to household head variable****
recode d11105 -7 -6 -5 -4 -3 -2 -1=.
rename d11105 reltohead

****Birth year mother****
rename  pla0002 mothbyr
recode mothbyr -8 -7 -5 -2 -1=.
 
****Death year mother****
fre pld0219
rename pld0219 mothdyr
recode mothdyr -8 -7 -2 -1=.
 
****Birth year father****
rename pla0001 fathbyr
recode fathbyr -8 -7 -5 -2 -1=.

****Death year father****
fre pld0217
rename pld0217 fathdyr
recode fathdyr -8 -7 -2 -1=.

********************************
**Note: convert into REAL values
********************************

**The CPI variable is y11101
fre y11101
rename y11101 cpi
*Base year: 2016
sum cpi if syear==2016
sum cpi if syear==1991
recode cpi -7 -2=.
gen cpiwest = cpi if west==1
gen cpieast = cpi if west==0
 
bysort syear: sum cpieast
bysort syear: sum cpiwest
 
**COMMENT: Need to generate a REAL value of all EURO variables
**COMMENT: East Germany has no CPI for 1990 and 1991 - use the one for 1992
foreach var of varlist pglabnet dispinc dispinclead hhinc_labor hhinc_asset inc_self inc_labor {
gen `var'_real=.
replace `var'_real = `var'/57*100 if syear==1990 & west==0
replace `var'_real = `var'/57*100 if syear==1991 & west==0
replace `var'_real = `var'/cpieast*100 if syear>1991 & west==0
}

foreach var of varlist pglabnet dispinc dispinclead hhinc_labor hhinc_asset inc_self inc_labor {
replace `var'_real = `var'/cpiwest*100 if west==1
}
 
**COMMENT: Now generate the logs of all variables
foreach var of varlist pglabnet dispinc hhinc_labor hhinc_asset inc_self inc_labor {
gen `var'1 = `var'_real
replace `var'1 = 1 if `var'_real==0
gen ln`var' = ln(`var'1)
drop `var'1
}

**COMMENT: Fix the moms and dads
*For some kids, the father or mother are only mentioned once and then not populated
*for the rest of the panel
sort pid syear
foreach var of varlist mnr fnr {
 recode `var' -8 -7 -6 -5 -4 -3 -2 -1=.
 by pid: egen double `var'_1=max(`var')
}

**COMMENT: Look at what you have done
sort pid syear fnr mnr
bro pid syear hid cid fnr* mnr* age if age<=20
bro pid syear hid cid fnr* mnr* age if mnr_1!=mnr & mnr!=.  
bro pid syear hid cid fnr* mnr* age if fnr_1!=fnr & fnr!=.
drop mnr fnr
rename mnr_1 mnr
rename fnr_1 fnr

****Birth year [GENERATED]****
sort pid syear
by pid: gen birthyear = syear - age

****Number of own children****
recode lb0285 -7 -5 -2 -1=.
rename lb0285 ownchild

**Save the dataset
save "C:\Users\your_folder_path\cleaned_gross_soepv36eu.dta", replace
