**********************************************************
**Session: Creating
**Purpose: Creating kids dataset
**Author:  Michele Ubaldi
**Date:    December 17, 2024
**********************************************************

clear all
set maxvar 32000

cd "C:\Users\your_folder_path\"
use cleaned_gross_soepv36eu.dta, clear
count

********************************************************************************
*************************Keep variables for analysis****************************
********************************************************************************

keep lifesat bmi weight height currhea hinstai tir rush mela relax energy phypain ///
	 lesswan_phy accomles_phy accomles_men careless_men soclim mcs pcs alccon becon ///
	 wicon spicon mixcon smoke unempreason age educdum nokid state hhinc_labor ///
	 hhinc_labor_real lnhhinc_labor hhinc_asset hhinc_asset_real lnhhinc_asset ///
	 inc_self inc_self_real lninc_self inc_labor inc_labor_real lninc_labor ///
	 job_explose1 job_explose2 dispinc logdispinc logdispinc1 dispinclead dispinc_real ///
	 dispinclead_real lndispinc occ selfemp civils military pensioner notemp ///
	 cureduc regunemp privemp west hgsize pgexpue jobsecworry pgmonth reltohead ///
	 mothbyr mothdyr fathbyr fathdyr cpi cpiwest pglabnet pglabnet_real lnpglabnet ///
	 mnr fnr birthyear ownchild syear hid pid cid sex migback parid fybirth mybirth ///
	 living* gebmonat pos_sib num_sib ///

 
format fnr mnr %11.0g 

**COMMENT: Drop children with no known mothers and fathers
sort pid syear
count if reltohead==3 & fnr==. & mnr==.

**COMMENT: Drop children with no mothers and fathers
drop if fnr==. & mnr==. 

**COMMENT: Rename all variables with a prefix c - so that we know they come from
**         the children samples
renvars _all, pref(c_) 
rename c_cid cid
rename c_pid pid
rename c_hid hid
rename c_syear syear

**WARNING: IDs - this is very important! Source: http://www.stata.com/manuals13/ddatatypes.pdf
**COMMENT: If you are storing identification numbers, the rounding could matter.
**         If the identification numbers are integers and take 9 digits or less,
**         store them as longs; otherwise, store them as doubles.
**N.B.:    doubles have 16 digits of accuracy**/

gen double matchfather = c_fnr
gen double matchmother = c_mnr
gen double pidkid=pid
drop pid

foreach var of varlist matchfather matchmother pidkid {
	 format `var' %11.0g 
	}


**Designate the first observation
by pidkid (syear), sort: gen byte first=_n==1


**COMMENT: Create a balanced panel. Fill in with missings if not in the panel
**         Now everyone has observations from 1984 until 2019. 
fillin pidkid syear

**COMMENT: Now fill in time-invariant variables
sort pidkid syear
foreach var of varlist c_sex c_fnr c_fybirth c_mnr c_mybirth matchfather matchmother c_birthyear cid {
	by pidkid: egen max`var' = max(`var')
	by pidkid: replace `var' = max`var' if `var'==.
	drop max`var'
}


**COMMENT: Age and birthyear fix
**COMMENT: Note that now you also have some kids with negative ages, as they
**         were not born yet 
by pidkid: replace c_age = syear - c_birthyear if c_age==.

****State and west/east missing indicators [IMPORTANT]****
gen c_state1 = c_state
replace c_state1 = 17 if c_state==.
sort matchmother matchfather syear

**COMMENT: Count
count
sort pidkid syear c_birthyear

**Save the dataset 
save  "C:\Users\your_folder_path\kids_soepv36eu.dta", replace
