***************************************************************************************
**Session: Creating
**Purpose: Creating "fathers" and "mothers" and "fathers and mothers" datasets
**Author:  Michele Ubaldi
**Date:    December 17, 2024
***************************************************************************************

clear all
set maxvar 32000

////////////////////////////////////////////////
// 	1.Fathers	///
///////////////////////////////////////////////

cd "C:\Users\your_folder_path\"
use cleaned_gross_soepv36eu.dta, clear

isid syear pid

********************************************************************************
*************************Keep variables for analysis****************************
********************************************************************************

keep lifesat bmi weight height currhea hinstai tir rush mela relax energy phypain ///
	 lesswan_phy accomles_phy accomles_men careless_men soclim mcs pcs alccon becon ///
	 wicon spicon mixcon smoke unempreason age educdum nokid state hhinc_labor ///
	 hhinc_labor_real lnhhinc_labor hhinc_asset hhinc_asset_real lnhhinc_asset ///
	 inc_self inc_self_real lninc_self inc_labor inc_labor_real lninc_labor ///
	 job_explose1 job_explose2 dispinc logdispinc logdispinc1 dispinclead dispinc_real ///
	 dispinclead_real lndispinc occ selfemp civils military pensioner notemp ///
	 cureduc regunemp privemp west hgsize pgexpue jobsecworry pgmonth reltohead ///
	 mothbyr mothdyr fathbyr fathdyr cpi cpiwest pglabnet pglabnet_real lnpglabnet ///
	 mnr fnr birthyear ownchild syear hid pid cid sex migback parid fybirth mybirth ///
	 living* gebmonat pos_sib num_sib h11101 h11102 ///


**COMMENT: Very important to run, it is a check, nothing should change
replace regunemp = . if occ==.


**Note: Keep only fathers, assuming fathers are all men
tab sex
keep if sex==1 
gen double matchfather = pid
gen double pidfather = pid
drop pid


**Note: Fix ages and birthyears
sort pid syear
by pid: egen max = max(birthyear)
by pid: replace birthyear = max if birthyear==. & max!=.

by pid syear: replace age = syear-birthyear if age==.
drop max
bro pid syear age birthyear

***Partner id for the mother
gen double matchpartner = pid

**Note: Rename all variables with a prefix f_* so that we know they come from the father sample
renvars _all, pref(f_) 
rename f_cid cid
gen hid = f_hid
rename f_syear syear
**Note: Keep the survey year for these fathers for later check on marital status condition
clonevar f_syear = syear
rename f_matchfather matchfather
rename f_pidfather pidfather
rename f_matchpartner matchpartner

**COMMENT: Important ID FORMAT
foreach var of varlist matchfather pidfather {
	 format `var' %11.0g 
	}

sort matchpartner hid syear 

save  "C:\Users\your_folder_path\fathers_soepv36eu.dta", replace



////////////////////////////////////////////////
// 	2. Mothers	///
///////////////////////////////////////////////

use cleaned_gross_soepv36eu.dta, clear

********************************************************************************
*************************Keep variables for analysis****************************
********************************************************************************

keep lifesat bmi weight height currhea hinstai tir rush mela relax energy phypain ///
	 lesswan_phy accomles_phy accomles_men careless_men soclim mcs pcs alccon becon ///
	 wicon spicon mixcon smoke unempreason age educdum nokid state hhinc_labor ///
	 hhinc_labor_real lnhhinc_labor hhinc_asset hhinc_asset_real lnhhinc_asset ///
	 inc_self inc_self_real lninc_self inc_labor inc_labor_real lninc_labor ///
	 job_explose1 job_explose2 dispinc logdispinc logdispinc1 dispinclead dispinc_real ///
	 dispinclead_real lndispinc occ selfemp civils military pensioner notemp ///
	 cureduc regunemp privemp west hgsize pgexpue jobsecworry pgmonth reltohead ///
	 mothbyr mothdyr fathbyr fathdyr cpi cpiwest pglabnet pglabnet_real lnpglabnet ///
	 mnr fnr birthyear ownchild syear hid pid cid sex migback parid fybirth mybirth ///
	 living* gebmonat pos_sib num_sib h11101 h11102 ///


**COMMENT: Allow the mothers to be also outside the labor force, not everyone works and especially with a newborn
**COMMENT: We focus only on working mothers, but we keep also non-working as in Nikolova
replace regunemp = . if occ==.

**Note: Keep only mothers, assume mothers are female
tab sex
keep if sex==2 
gen double matchmother = pid
gen double pidmother = pid
drop pid


**Note: Fix ages and birthyears
sort pid syear
by pid: egen max = max(birthyear)
by pid: replace birthyear = max if birthyear==. & max!=.

by pid syear: replace age = syear-birthyear if age==.
drop max
bro pid syear age birthyear


***Partner ID to merge with the fathers
gen double matchpartner = parid


**Note: Rename all variables with a prefix m_* so that we know they come from the mothers' samples
renvars _all, pref(m_) 
gen hid = m_hid
rename m_syear syear
**Note: Keep the survey year for these mothers for later check on marital status condition
clonevar m_syear = syear
rename m_matchmother matchmother
rename m_pidmother  pidmother
rename m_matchpartner matchpartner
rename m_cid cid


**COMMENT: Important ID FORMAT
foreach var of varlist matchmother pidmother {
	 format `var' %11.0g 
	}
	
sort matchpartner hid syear 
save  "C:\Users\your_folder_path\mothers_soepv36eu.dta", replace


////////////////////////////////////////////////
// 	3. Parents (mothers and fathers)	///
///////////////////////////////////////////////

use mothers.dta, clear

**COMMENT: We merge mothers and fathers samples
merge m:1 matchpartner hid syear using "C:\Users\your_folder_path\fathers_soepv36eu.dta"
keep if _merge==3
drop _merge
keep matchpartner pidmother pidfather hid matchmother matchfather *syear cid

count

save "C:\Users\your_folder_path\mothersfathers_soepv36eu.dta", replace
