*********************************************************************************
**Session: Merging
**Purpose: Merging kids with parental data
**Author:  Michele Ubaldi
**Date:    December 17, 2024
*********************************************************************************

clear all
set maxvar 32000

/////////////////////////////////////////////
// 	Kids, mothers, and fathers	///
/////////////////////////////////////////////

cd "C:\Users\your_folder_path\"
use kids_soepv36eu.dta, clear
cap drop _merge

**WARNING: Do not match on household identifier, you will lose the kids whose fathers do not live in the same HH 
**WARNING: There is one problematic mother - who is both a mother and a kid c_mnr= 31025402


**Note: Match with the mother in the same year and who live in the same HH
**		   One big problem is the fact that hid is not populated throughout 
merge m:1 matchmother cid syear using "mothers.dta"
rename _merge merge_mother


**Note: Match with the fathers in the same year and who live in the same households
merge m:1 matchfather cid syear using "fathers.dta"
rename _merge merge_father
bro pidkid hid syear c_age matchmother matchfather matchpartner pidmother pidfather if pidmother==.| pidfather==.

**Note: Drop individuals that do not have kids
drop if merge_mother==2 & pidkid==.
drop if merge_father==2 & pidkid==.

**Note: Drop kids with no parents in mothers.dta or fathers.dta files
drop if merge_mother==1 & merge_father==1

**COMMENT: All have both of their parents identified and living in the same HH
**COMMENT: Now we merge with the mothers and fathers, this is the partner data,
**		   to make sure that kids live with actual married couples
merge m:1 matchmother matchfather cid syear using "mothersfathers.dta"
gen nonbroken = 1 if _merge==3
**Note: Drop couple that have no kids in the sample
drop if _merge==2
rename _merge merge_nonbroken

count

**Save the dataset
save all_families_soepv36eu.dta, replace
